@@ -1,8 +1,7 @@
 #' View the 'CDC PLACES' data dictionary
 #'
 #' This function provides the user with a data frame that shows all of the available measures in the PLACES data set and for which release years the measures are included.
-#'#'
-#'@importFrom httr2 request req_perform resp_body_string
+#'
 #'@importFrom yyjsonr read_json_str
 #'@importFrom curl has_internet
 #'
@@ -22,12 +21,13 @@ get_dictionary <- function(){
     return(invisible(NULL))
   }
 
-  check_api("https://data.cdc.gov/resource/m35w-spkz.json")
+  base <- "https://data.cdc.gov/resource/m35w-spkz.json"
 
-  resp <- httr2::request("https://data.cdc.gov/resource/m35w-spkz.json") |>
-    httr2::req_perform()
+  check_api(base)
 
-  resp |>
-    httr2::resp_body_string() |>
+  resp <- curl::curl_fetch_memory(base)
+
+  resp$content |>
+    rawToChar() |>
     yyjsonr::read_json_str()
 }
